@@ -17,6 +17,14 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  */
 
+/**
+ * SECTION:gdict-speller
+ * @short_description: Display matching words
+ *
+ * #GdictSpeller is a widget showing a list of words returned by a 
+ * #GdictContext query, using a specific database and a matching strategy.
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -56,8 +64,6 @@ struct _GdictSpellerPrivate
   GtkListStore *store;
   gint results;
 
-  GtkTooltips *tips;
-  
   guint start_id;
   guint end_id;
   guint match_id;
@@ -169,9 +175,6 @@ gdict_speller_finalize (GObject *gobject)
   if (priv->busy_cursor)
     gdk_cursor_unref (priv->busy_cursor);
 
-  if (priv->tips)
-    g_object_unref (priv->tips);
-
   g_free (priv->strategy);
   g_free (priv->database);
   g_free (priv->word);
@@ -343,13 +346,12 @@ gdict_speller_constructor (GType                  type,
 		  	gtk_image_new_from_stock (GTK_STOCK_CLEAR,
 						  GTK_ICON_SIZE_SMALL_TOOLBAR));
   g_signal_connect (priv->clear_button, "clicked",
-		    clear_button_clicked_cb,
+		    G_CALLBACK (clear_button_clicked_cb),
 		    speller);
   gtk_box_pack_start (GTK_BOX (hbox), priv->clear_button, FALSE, FALSE, 0);
   gtk_widget_show (priv->clear_button);
-  gtk_tooltips_set_tip (priv->tips, priv->clear_button,
-		        _("Clear the list of similar words"),
-			NULL);
+  gtk_widget_set_tooltip_text (priv->clear_button,
+                               _("Clear the list of similar words"));
 
   gtk_box_pack_end (GTK_BOX (speller), hbox, FALSE, FALSE, 0);
   gtk_widget_show (hbox);
@@ -424,9 +426,6 @@ gdict_speller_init (GdictSpeller *speller)
 		                    G_TYPE_STRING, /* db_name */
 				    G_TYPE_STRING  /* word */);
 
-  priv->tips = gtk_tooltips_new ();
-  g_object_ref_sink (G_OBJECT (priv->tips));
-  
   priv->start_id = 0;
   priv->end_id = 0;
   priv->match_id = 0;
@@ -507,6 +506,15 @@ gdict_speller_get_context (GdictSpeller *speller)
   return speller->priv->context;
 }
 
+/**
+ * gdict_speller_set_database:
+ * @speller: a #GdictSpeller
+ * @database: FIXME
+ *
+ * FIXME
+ *
+ * Since:
+ */
 void
 gdict_speller_set_database (GdictSpeller *speller,
 			    const gchar  *database)
