@@ -19,8 +19,13 @@
 
     ---------------------------------------------------------------------- */
 
+#include "config.h"
+
+#include <string.h>
+
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+
 #include "logview.h"
 #include "logrtns.h"
 #include "log_repaint.h"
@@ -90,7 +95,7 @@ tree_path_find_row (GtkTreeModel *model, GtkTreePath *path, gboolean has_date)
         for (j = 0; j < indices[0]; j++) {
             date_path = gtk_tree_path_new_from_indices (j, -1);
             gtk_tree_model_get_iter (model, &iter, date_path);
-            row += gtk_tree_model_iter_n_children (model, &iter) - 1;
+            row += gtk_tree_model_iter_n_children (model, &iter);
         }
         if (gtk_tree_path_get_depth (path) > 1)
             row += indices[1];
@@ -164,23 +169,29 @@ static void
 logview_update_statusbar (LogviewWindow *logview)
 {
    char *statusbar_text;
-   char *size, *modified;
+   char *size, *modified, *index;
    Log *log;
 
    g_assert (LOGVIEW_IS_WINDOW (logview));
 
    log = logview->curlog;
 
-   if (log == NULL) { 
+   if (log == NULL) {
        gtk_statusbar_pop (GTK_STATUSBAR (logview->statusbar), 0);
        return;
    }
+   
+   /* ctime returned string has "\n\0" causes statusbar display a invalid char */
+   modified = ctime (&(log->stats->file_time));
+   index = strrchr (modified, '\n');
+   if (index && *index != '\0')
+     *index = '\0';
 
-   modified = g_strdup_printf (_("last update : %s"), ctime (&(log->stats->file_time)));   
+   modified = g_strdup_printf (_("last update: %s"), modified);
    size = gnome_vfs_format_file_size_for_display (log->stats->file_size);
    statusbar_text = g_strdup_printf (_("%d lines (%s) - %s"), 
                                      log->total_lines, size, modified);
-
+                                     
    if (statusbar_text) {
        gtk_statusbar_pop (GTK_STATUSBAR(logview->statusbar), 0);
        gtk_statusbar_push (GTK_STATUSBAR(logview->statusbar), 0, statusbar_text);
@@ -305,7 +316,7 @@ log_add_new_log_lines (Log *log)
     } else {
       iter_ptr = NULL;
     }  
-                
+ 
     for (i=log->displayed_lines; i<log->total_lines; i++) {
 
         line = log->lines[i];
